use std::fs::File;
use std::io::Read;
use std::str::FromStr;
use crate::consts::{DEVICE_FILE, key};
use std::time::{SystemTime, UNIX_EPOCH};

pub struct Request{
    product:String,
    partner_id:String,
    os:String,
    os_version:String,
    device_id:String,
    request_id:String,
    version:String,
    release:String,
    timestamp:String,
    sign:String,
}

struct Config{
    product:String,
    partner_id:String,
    device_id:String,
    version:String,
    release:String,
}

fn read_config(request_id:String, current_dir:String,os:String,os_version:String) -> Result<Request,Err>{

    let path:String=current_dir+DEVICE_FILE;

    let mut config_file =match File::open(path){
        Ok(mut config_file)=>config_file,
        Err(error)=>return Result::Err(error)
    };
    let mut json_str:String;
    config_file.read_to_string(&mut json_str);
    let json_str:&str=json_str.as_str();
    let json:Config=match serde_json::from_str(json_str) {
        Ok(json)=>json,
        Err(error)=>return Result::Err(error)
    };

    let request:Request=Request{
        product:json.product,
        partner_id: json.partner_id,
        os: os,
        os_version: os_version,
        device_id: json.device_id,
        request_id: request_id,
        version: json.version,
        release: json.release,
        timestamp:match SystemTime::now().duration_since(UNIX_EPOCH) {
            Ok(n) => n.as_secs().to_string(),
            Err(error) => return Result::Err(error)
        },
        sign: String::from(key),
    };

    return Result::Ok(request);
}